==> xoonips-2.00a.tar.gz: xoonips-2.00a/xoonips/include/checklogin.php <==
<?php
// $Id: checklogin.php,v 1.4.4.1 2006/06/16 13:46:26 makotonton Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //
// Author: Kazumi Ono (AKA onokazu)                                          //
// URL: http://www.xoops.org/ http://jp.xoops.org/  http://www.myweb.ne.jp/  //
// Project: The XOOPS Project (http://www.xoops.org/)                        //
// ------------------------------------------------------------------------- //
include_once 'condefs.php';
require_once XOOPS_ROOT_PATH.'/modules/xoonips/include/lib.php';

if (!defined('XOOPS_ROOT_PATH')) {
	exit();
}
include_once XOOPS_ROOT_PATH.'/language/'.$xoopsConfig['language'].'/user.php';
$uname = !isset($_POST['uname']) ? '' : trim($_POST['uname']);
$pass = !isset($_POST['pass']) ? '' : trim($_POST['pass']);
if ($uname == '' || $pass == '') {
	// Record events (login failure)
	xnp_insert_event( XNPSID_GUEST, ETID_LOGIN_FAILURE, time(), UID_GUEST, xnpGetRemoteHost(), array( 'additional_info' => $uname ) );
	
	redirect_header(XOOPS_URL.'/modules/xoonips/user.php', 1, _US_INCORRECTLOGIN);
	exit();
}
$member_handler =& xoops_gethandler('member');
$myts =& MyTextsanitizer::getInstance();
$user =& $member_handler->loginUser(addslashes($myts->stripSlashesGPC($uname)), addslashes($myts->stripSlashesGPC($pass)));
if (false != $user) {
	if (0 == $user->getVar('level')) {
		redirect_header(XOOPS_URL.'/index.php', 5, _US_NOACTTPADM);
		exit();
	}
	if ($xoopsConfig['closesite'] == 1) {
		$allowed = false;
		foreach ($user->getGroups() as $group) {
			if (in_array($group, $xoopsConfig['closesite_okgrp']) || XOOPS_GROUP_ADMIN == $group) {
				$allowed = true;
				break;
			}
		}
		if (!$allowed) {
			redirect_header(XOOPS_URL.'/index.php', 1, _NOPERM);
			exit();
		}
	}
	$user->setVar('last_login', time());
	if (!$member_handler->insertUser($user)) {
	}
	$_SESSION = array();
	$_SESSION['xoopsUserId'] = $user->getVar('uid');
	$_SESSION['xoopsUserGroups'] = $user->getGroups();
	if ($xoopsConfig['use_mysession'] && $xoopsConfig['session_name'] != '') {
		setcookie($xoopsConfig['session_name'], session_id(), time()+(60 * $xoopsConfig['session_expire']), '/',  '', 0);
	}
	$user_theme = $user->getVar('theme');
	if (in_array($user_theme, $xoopsConfig['theme_set_allowed'])) {
		$_SESSION['xoopsUserTheme'] = $user_theme;
	}
	if (!empty($_POST['xoops_redirect']) && !strpos($_POST['xoops_redirect'], 'register')) {
		$parsed = parse_url(XOOPS_URL);
		$url = isset($parsed['scheme']) ? $parsed['scheme'].'://' : 'http://';
		if (isset($parsed['host'])) {
			$url .= isset($parsed['port']) ?$parsed['host'].':'.$parsed['port'].trim($_POST['xoops_redirect']): $parsed['host'].trim($_POST['xoops_redirect']);
		} else {
			$url = xoops_getenv('HTTP_HOST').trim($_POST['xoops_redirect']);
		}
	} else {
		$url = XOOPS_URL.'/index.php';
	}

	// set cookie for autologin
	//if (!empty($_POST['rememberme'])) {
	//	$expire = time() + $xoopsConfig['session_expire'] * 60;
	//	setcookie('autologin_uname', $uname, $expire, '/', '', 0);
	//	setcookie('autologin_pass', md5($pass), $expire, '/', '', 0);
	//}

	// RMV-NOTIFY
	// Perform some maintenance of notification records
	$notification_handler =& xoops_gethandler('notification');
	$notification_handler->doLoginMaintenance($user->getVar('uid'));
	
	xnp_load_init_create_session();
	
	// Record events(login success)
	xnp_insert_event( XNPSID_GUEST, ETID_LOGIN_SUCCESS, time(), $user->getVar('uid'), xnpGetRemoteHost(), array() );
	
	redirect_header($url, 1, sprintf(_US_LOGGINGU, $user->getVar('uname')));
} else {
	// Record events(login failure)
	xnp_insert_event( XNPSID_GUEST, ETID_LOGIN_FAILURE, time(), UID_GUEST, xnpGetRemoteHost(), array( 'additional_info' => $uname ) );
	
	redirect_header(XOOPS_URL.'/modules/xoonips/user.php',1,_US_INCORRECTLOGIN);
}
exit();
?>

==> xoonips-3.24a.tar.gz: xoonips-3.24a/xoonips/include/checklogin.php <==
<?php
// $Id: checklogin.php,v 1.8.2.1 2007/03/22 05:25:15 tani Exp $
//  ------------------------------------------------------------------------ //
//                XOOPS - PHP Content Management System                      //
//                    Copyright (c) 2000 XOOPS.org                           //
//                       <http://www.xoops.org/>                             //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //
// Author: Kazumi Ono (AKA onokazu)                                          //
// URL: http://www.xoops.org/ http://jp.xoops.org/  http://www.myweb.ne.jp/  //
// Project: The XOOPS Project (http://www.xoops.org/)                        //
// ------------------------------------------------------------------------- //
// XooNIps modifies like below                                               //
// - insert login event(2005/6/29)                                           //
// - create XooNIps session(2005/7/19)                                       //
// ------------------------------------------------------------------------- //
include_once 'condefs.php';
require_once XOOPS_ROOT_PATH.'/modules/xoonips/include/lib.php';

if (!defined('XOOPS_ROOT_PATH')) {
	exit();
}
include_once XOOPS_ROOT_PATH.'/language/'.$xoopsConfig['language'].'/user.php';
$uname = !isset($_POST['uname']) ? '' : trim($_POST['uname']);
$pass = !isset($_POST['pass']) ? '' : trim($_POST['pass']);
if ($uname == '' || $pass == '') {
	// Record events (login failure)
	xnp_insert_event( XNPSID_GUEST, ETID_LOGIN_FAILURE, time(), UID_GUEST, xnpGetRemoteHost(), array( 'additional_info' => $uname ) );
	
	redirect_header(XOOPS_URL.'/modules/xoonips/user.php', 1, _US_INCORRECTLOGIN);
	exit();
}
$member_handler =& xoops_gethandler('member');
$myts =& MyTextsanitizer::getInstance();
$user =& $member_handler->loginUser(addslashes($myts->stripSlashesGPC($uname)), addslashes($myts->stripSlashesGPC($pass)));
if (false != $user) {
	if (0 == $user->getVar('level')) {
		redirect_header(XOOPS_URL.'/index.php', 5, _US_NOACTTPADM);
		exit();
	}
	if ($xoopsConfig['closesite'] == 1) {
		$allowed = false;
		foreach ($user->getGroups() as $group) {
			if (in_array($group, $xoopsConfig['closesite_okgrp']) || XOOPS_GROUP_ADMIN == $group) {
				$allowed = true;
				break;
			}
		}
		if (!$allowed) {
			redirect_header(XOOPS_URL.'/index.php', 1, _NOPERM);
			exit();
		}
	}
	$user->setVar('last_login', time());
	if (!$member_handler->insertUser($user)) {
	}
	$_SESSION = array();
	$_SESSION['xoopsUserId'] = $user->getVar('uid');
	$_SESSION['xoopsUserGroups'] = $user->getGroups();
	if ($xoopsConfig['use_mysession'] && $xoopsConfig['session_name'] != '') {
		setcookie($xoopsConfig['session_name'], session_id(), time()+(60 * $xoopsConfig['session_expire']), '/',  '', 0);
	}
	$user_theme = $user->getVar('theme');
	if (in_array($user_theme, $xoopsConfig['theme_set_allowed'])) {
		$_SESSION['xoopsUserTheme'] = $user_theme;
	}
	if (!empty($_POST['xoops_redirect']) && !strpos($_POST['xoops_redirect'], 'register')) {
		$parsed = parse_url(XOOPS_URL);
		$url = isset($parsed['scheme']) ? $parsed['scheme'].'://' : 'http://';
		if (isset($parsed['host'])) {
			$url .= isset($parsed['port']) ?$parsed['host'].':'.$parsed['port'].trim($_POST['xoops_redirect']): $parsed['host'].trim($_POST['xoops_redirect']);
		} else {
			$url = xoops_getenv('HTTP_HOST').trim($_POST['xoops_redirect']);
		}
	} else {
		$url = XOOPS_URL.'/index.php';
	}

	// set cookie for autologin
	//if (!empty($_POST['rememberme'])) {
	//	$expire = time() + $xoopsConfig['session_expire'] * 60;
	//	setcookie('autologin_uname', $uname, $expire, '/', '', 0);
	//	setcookie('autologin_pass', md5($pass), $expire, '/', '', 0);
	//}

	// RMV-NOTIFY
	// Perform some maintenance of notification records
	$notification_handler =& xoops_gethandler('notification');
	$notification_handler->doLoginMaintenance($user->getVar('uid'));
	
	xnp_load_init_create_session();
	
	// Record events(login success)
	$uid = $user->getVar('uid');
	xnp_insert_event( XNPSID_GUEST, ETID_LOGIN_SUCCESS, time(), $uid, xnpGetRemoteHost(), array() );
	
	$sql = "insert into " . $xoopsDB->prefix('xoonips_session') . "(sess_id, updated, uid) values ( '".addslashes(session_id())."', now(), $uid )";
	$xoopsDB->query( $sql );
	
	xnpGcSession();
	
	if ( strstr($url, 'user.php') ) {
		if ( isset($_SESSION["back_url"]) ){
			$_SESSION["back_url"] = '';
		}
		xnpRedirectHeader($url, 1, sprintf(_US_LOGGINGU, $user->getVar('uname')));
	} else {
		redirect_header($url, 1, sprintf(_US_LOGGINGU, $user->getVar('uname')));
	}
} else {
	// Record events(login failure)
	xnp_insert_event( XNPSID_GUEST, ETID_LOGIN_FAILURE, time(), UID_GUEST, xnpGetRemoteHost(), array( 'additional_info' => $uname ) );
	
	redirect_header(XOOPS_URL.'/modules/xoonips/user.php',1,_US_INCORRECTLOGIN);
}
exit();
?>
